@@ -6,7 +6,7 @@ use utf8;
 
 BEGIN {
 	$HTML::HTML5::ToText::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::HTML5::ToText::VERSION   = '0.002';
+	$HTML::HTML5::ToText::VERSION   = '0.003';
 }
 
 use Moose;
@@ -14,7 +14,7 @@ with 'MooseX::Traits';
 
 has '+_trait_namespace' => (
 	default => join('::', __PACKAGE__, 'Trait'),
-	);
+);
 
 use HTML::HTML5::Parser;
 use XML::LibXML::PrettyPrint;
@@ -82,7 +82,7 @@ sub process_string
 	shift->process(
 		HTML::HTML5::Parser->load_html(string => shift, URI => shift),
 		'no_clone',
-		);
+	);
 }
 
 sub textnode
@@ -102,7 +102,7 @@ sub _inline
 		{
 			$return .= $self->textnode($kid, %args);
 		}
-		else
+		elsif ($kid->isa('XML::LibXML::Element'))
 		{
 			my $elem = uc $kid->nodeName;
 			$return .= $self->$elem($kid, %args);
@@ -123,7 +123,7 @@ sub _block
 		{
 			$return .= $self->textnode($kid, %args);
 		}
-		else
+		elsif ($kid->isa('XML::LibXML::Element'))
 		{
 			my $elem = uc $kid->nodeName;
 			my $str  = $self->$elem($kid, %args);
@@ -132,12 +132,12 @@ sub _block
 			{
 				$str =~ s{^\n}{};
 			}
-
+			
 			if ($str =~ m{\n$} and not $kid->nextSibling)
 			{
 				$str =~ s{\n$}{};
 			}
-
+			
 			$return .= $str;
 		}
 	}
@@ -354,7 +354,7 @@ without Moose's strange brand of meta-programming!
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 by Toby Inkster.
+This software is copyright (c) 2012-2013 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
